@@ -6,9 +6,9 @@ Type annotations for kafka service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kafka.literals import BrokerAZDistribution
+    from mypy_boto3_kafka.literals import BrokerAZDistributionType
 
-    data: BrokerAZDistribution = "DEFAULT"
+    data: BrokerAZDistributionType = "DEFAULT"
     ```
 """
 import sys
@@ -20,12 +20,12 @@ else:
 
 
 __all__ = (
-    "BrokerAZDistribution",
-    "ClientBroker",
-    "ClusterState",
-    "ConfigurationState",
-    "EnhancedMonitoring",
-    "KafkaVersionStatus",
+    "BrokerAZDistributionType",
+    "ClientBrokerType",
+    "ClusterStateType",
+    "ConfigurationStateType",
+    "EnhancedMonitoringType",
+    "KafkaVersionStatusType",
     "ListClusterOperationsPaginatorName",
     "ListClustersPaginatorName",
     "ListConfigurationRevisionsPaginatorName",
@@ -33,13 +33,13 @@ __all__ = (
     "ListKafkaVersionsPaginatorName",
     "ListNodesPaginatorName",
     "ListScramSecretsPaginatorName",
-    "NodeType",
+    "NodeTypeType",
 )
 
 
-BrokerAZDistribution = Literal["DEFAULT"]
-ClientBroker = Literal["PLAINTEXT", "TLS", "TLS_PLAINTEXT"]
-ClusterState = Literal[
+BrokerAZDistributionType = Literal["DEFAULT"]
+ClientBrokerType = Literal["PLAINTEXT", "TLS", "TLS_PLAINTEXT"]
+ClusterStateType = Literal[
     "ACTIVE",
     "CREATING",
     "DELETING",
@@ -49,11 +49,11 @@ ClusterState = Literal[
     "REBOOTING_BROKER",
     "UPDATING",
 ]
-ConfigurationState = Literal["ACTIVE", "DELETE_FAILED", "DELETING"]
-EnhancedMonitoring = Literal[
+ConfigurationStateType = Literal["ACTIVE", "DELETE_FAILED", "DELETING"]
+EnhancedMonitoringType = Literal[
     "DEFAULT", "PER_BROKER", "PER_TOPIC_PER_BROKER", "PER_TOPIC_PER_PARTITION"
 ]
-KafkaVersionStatus = Literal["ACTIVE", "DEPRECATED"]
+KafkaVersionStatusType = Literal["ACTIVE", "DEPRECATED"]
 ListClusterOperationsPaginatorName = Literal["list_cluster_operations"]
 ListClustersPaginatorName = Literal["list_clusters"]
 ListConfigurationRevisionsPaginatorName = Literal["list_configuration_revisions"]
@@ -61,4 +61,4 @@ ListConfigurationsPaginatorName = Literal["list_configurations"]
 ListKafkaVersionsPaginatorName = Literal["list_kafka_versions"]
 ListNodesPaginatorName = Literal["list_nodes"]
 ListScramSecretsPaginatorName = Literal["list_scram_secrets"]
-NodeType = Literal["BROKER"]
+NodeTypeType = Literal["BROKER"]
